@@ -6,21 +6,27 @@ from astropy.tests.helper import remote_data
 
 from ... import esasky
 
+
+ESASkyClass = esasky.core.ESASkyClass()
+
+
 @remote_data
 class TestESASky:
-        
+
+    ESASkyClass._isTest = "Remote Test"
+
     def test_esasky_query_region_maps(self):
-        result = esasky.core.ESASkyClass().query_region_maps("M51", "5 arcmin")
+        result = ESASkyClass.query_region_maps("M51", "5 arcmin")
         assert isinstance(result, TableList)
 
     def test_esasky_query_object_maps(self):
-        result = esasky.core.ESASkyClass().query_object_maps("M51")
+        result = ESASkyClass.query_object_maps("M51")
         assert isinstance(result, TableList)
-        
+
     def test_esasky_query_region_catalogs(self):
-        result = esasky.core.ESASkyClass().query_region_catalogs("M51", "5 arcmin")
+        result = ESASkyClass.query_region_catalogs("M51", "5 arcmin")
         assert isinstance(result, TableList)
-        
+
     def test_esasky_query_object_catalogs(self):
-        result = esasky.core.ESASkyClass().query_object_maps("M51")
+        result = ESASkyClass.query_object_catalogs("M51")
         assert isinstance(result, TableList)
