@@ -46,8 +46,8 @@ class EsoClass(QueryWithLogin):
         self._instrument_list = None
         self._survey_list = None
 
-    def _activate_form(self, response, form_index=0, inputs={}, cache=True,
-                       method=None):
+    def _activate_form(self, response, form_index=0, form_id=None, inputs={},
+                       cache=True, method=None):
         """
         Parameters
         ----------
@@ -56,7 +56,10 @@ class EsoClass(QueryWithLogin):
         """
         # Extract form from response
         root = BeautifulSoup(response.content, 'html5lib')
-        form = root.find_all('form')[form_index]
+        if form_id is None:
+            form = root.find_all('form')[form_index]
+        else:
+            form = root.find_all('form', id=form_id)[form_index]
         # Construct base url
         form_action = form.get('action')
         if "://" in form_action:
@@ -106,7 +109,10 @@ class EsoClass(QueryWithLogin):
                     else:
                         for option in form_elem.select('option'):
                             if option.get('selected') is not None:
-                                value.append(option.string)
+                                # bs4 NavigableString types have bad,
+                                # undesirable properties that result
+                                # in recursion errors when caching
+                                value.append(str(option.string))
                 else:
                     if form_elem.select('option[value]'):
                         for option in form_elem.select('option[value]'):
@@ -120,10 +126,10 @@ class EsoClass(QueryWithLogin):
                         # survey form just uses text, not value
                         for option in form_elem.select('option'):
                             if option.get('selected') is not None:
-                                value = option.string
+                                value = str(option.string)
                         # select the first option field if none is selected
                         if value is None:
-                            value = form_elem.select('option')[0].string
+                            value = str(form_elem.select('option')[0].string)
 
             if key in inputs:
                 if isinstance(inputs[key], list):
@@ -131,7 +137,8 @@ class EsoClass(QueryWithLogin):
                     value = inputs[key]
                 else:
                     value = str(inputs[key])
-            if (key is not None):# and (value is not None):
+
+            if (key is not None):  # and (value is not None):
                 if fmt == 'multipart/form-data':
                     if is_file:
                         payload.append(
@@ -139,17 +146,29 @@ class EsoClass(QueryWithLogin):
                     else:
                         if type(value) is list:
                             for v in value:
-                                payload.append((key, ('', v)))
+                                entry = (key, ('', v))
+                                # Prevent redundant key, value pairs
+                                # (can happen if the form repeats them)
+                                if entry not in payload:
+                                    payload.append(entry)
                         elif value is None:
-                            payload.append((key, ('', '')))
+                            entry = (key, ('', ''))
+                            if entry not in payload:
+                                payload.append(entry)
                         else:
-                            payload.append((key, ('', value)))
+                            entry = (key, ('', value))
+                            if entry not in payload:
+                                payload.append(entry)
                 else:
                     if type(value) is list:
                         for v in value:
-                            payload.append((key, v))
+                            entry = (key, v)
+                            if entry not in payload:
+                                payload.append(entry)
                     else:
-                        payload.append((key, value))
+                        entry = (key, value)
+                        if entry not in payload:
+                            payload.append(entry)
 
         # for future debugging
         self._payload = payload
@@ -214,6 +233,7 @@ class EsoClass(QueryWithLogin):
         # Do not cache pieces of the login process
         login_response = self._request("GET", "https://www.eso.org/sso/login",
                                        cache=False)
+        # login form: method=post action=login [no id]
         login_result_response = self._activate_form(
             login_response, form_index=-1, inputs={'username': username,
                                                    'password': password})
@@ -250,6 +270,7 @@ class EsoClass(QueryWithLogin):
                     if instrument not in self._instrument_list:
                         self._instrument_list.append(instrument)
             self._instrument_list.append(u'harps')
+            self._instrument_list.append(u'feros')
         return self._instrument_list
 
     def list_surveys(self, cache=True):
@@ -327,6 +348,7 @@ class EsoClass(QueryWithLogin):
                 query_dict["max_rows_returned"] = 10000
 
             survey_response = self._activate_form(survey_form, form_index=0,
+                                                  form_id='queryform',
                                                   inputs=query_dict, cache=cache)
 
             content = survey_response.content
@@ -374,9 +396,7 @@ class EsoClass(QueryWithLogin):
 
         """
 
-        if instrument in ('feros', 'harps'):
-            url = 'http://archive.eso.org/wdb/wdb/eso/repro/form'
-        elif instrument == 'grond':
+        if instrument in ('feros', 'harps', 'grond'):
             url = 'http://archive.eso.org/wdb/wdb/eso/eso_archive_main/form'
         else:
             url = ("http://archive.eso.org/wdb/wdb/eso/{0}/form"
@@ -396,12 +416,10 @@ class EsoClass(QueryWithLogin):
 
             # Default to returning the DP.ID since it is needed for header
             # acquisition
-            query_dict['tab_dp_id'] = (kwargs.pop('tab_dp_id')
-                                       if 'tab_db_id' in kwargs
-                                       else 'on')
+            query_dict['tab_dp_id'] = kwargs.pop('tab_dp_id', 'on')
 
-            if instrument == 'grond':
-                query_dict['instrument'] = "GROND"
+            if instrument in ('feros', 'harps', 'ground'):
+                query_dict['instrument'] = instrument.upper()
 
             for k in columns:
                 query_dict["tab_" + k] = True
@@ -410,8 +428,10 @@ class EsoClass(QueryWithLogin):
             else:
                 query_dict["max_rows_returned"] = 10000
             # used to be form 0, but now there's a new 'logout' form at the top
+            # (form_index = -1 and 0 both work now that form_id is included)
             instrument_response = self._activate_form(instrument_form,
                                                       form_index=-1,
+                                                      form_id='queryform',
                                                       inputs=query_dict,
                                                       cache=cache)
 
@@ -499,13 +519,13 @@ class EsoClass(QueryWithLogin):
 
     def data_retrieval(self, datasets):
         """
-        DEPRECATED: see ``retrieve_datasets``
+        DEPRECATED: see ``retrieve_data``
         """
 
         warnings.warn("data_retrieval has been replaced with retrieve_data",
                       DeprecationWarning)
 
-    def retrieve_data(self, datasets, cache=True):
+    def retrieve_data(self, datasets, cache=True, continuation=False):
         """
         Retrieve a list of datasets form the ESO archive.
 
@@ -552,13 +572,22 @@ class EsoClass(QueryWithLogin):
                                               local_filename)
             if os.path.exists(local_filename):
                 log.info("Found {0}.fits...".format(dataset))
-                files.append(local_filename)
+                if continuation:
+                    datasets_to_download.append(dataset)
+                else:
+                    files.append(local_filename)
             elif os.path.exists(local_filename + ".Z"):
                 log.info("Found {0}.fits.Z...".format(dataset))
-                files.append(local_filename + ".Z")
+                if continuation:
+                    datasets_to_download.append(dataset)
+                else:
+                    files.append(local_filename + ".Z")
             elif os.path.exists(local_filename + ".fz"):  # RICE-compressed
                 log.info("Found {0}.fits.fz...".format(dataset))
-                files.append(local_filename + ".fz")
+                if continuation:
+                    datasets_to_download.append(dataset)
+                else:
+                    files.append(local_filename + ".fz")
             else:
                 datasets_to_download.append(dataset)
 
@@ -591,6 +620,7 @@ class EsoClass(QueryWithLogin):
 
                 # TODO: There may be another screen for Not Authorized; that
                 # should be included too
+                # form name is "retrieve"; no id
                 data_download_form = self._activate_form(
                     data_confirmation_form, form_index=-1)
                 log.info("Staging form is at {0}."
@@ -617,7 +647,8 @@ class EsoClass(QueryWithLogin):
             for fileId in root.select('input[name=fileId]'):
                 fileLink = ("http://dataportal.eso.org/dataPortal" +
                             fileId.attrs['value'].split()[1])
-                filename = self._request("GET", fileLink, save=True)
+                filename = self._request("GET", fileLink, save=True,
+                                         continuation=True)
                 files.append(system_tools.gunzip(filename))
         # Empty the redirect cache of this request session
         self._session.redirect_cache.clear()
@@ -671,8 +702,8 @@ class EsoClass(QueryWithLogin):
 
             apex_form = self._request("GET", apex_query_url, cache=cache)
             apex_response = self._activate_form(
-                apex_form, form_index=0, inputs=payload, cache=cache,
-                method='application/x-www-form-urlencoded')
+                apex_form, form_id='queryform', form_index=0, inputs=payload,
+                cache=cache, method='application/x-www-form-urlencoded')
 
             content = apex_response.content
             if _check_response(content):
@@ -825,4 +856,5 @@ class EsoClass(QueryWithLogin):
         print("\n".join(result_string))
         return result_string
 
+
 Eso = EsoClass()
