@@ -3,7 +3,7 @@ from __future__ import print_function
 import os
 import requests
 
-from astropy.tests.helper import pytest
+import pytest
 import astropy.units as u
 from astropy.table import Table
 
@@ -16,23 +16,30 @@ def data_path(filename):
     data_dir = os.path.join(os.path.dirname(__file__), 'data')
     return os.path.join(data_dir, filename)
 
+
 DATA_FILES = {'votable': 'votable.xml',
               'archive': 'archive_html.html',
-             }
+              }
 
 
 @pytest.fixture
 def patch_parse_coordinates(request):
     def parse_coordinates_mock_return(c):
         return c
-    mp = request.getfuncargvalue("monkeypatch")
+    try:
+        mp = request.getfixturevalue("monkeypatch")
+    except AttributeError:  # pytest < 3
+        mp = request.getfuncargvalue("monkeypatch")
     mp.setattr(commons, 'parse_coordinates', parse_coordinates_mock_return)
     return mp
 
 
 @pytest.fixture
 def patch_post(request):
-    mp = request.getfuncargvalue("monkeypatch")
+    try:
+        mp = request.getfixturevalue("monkeypatch")
+    except AttributeError:  # pytest < 3
+        mp = request.getfuncargvalue("monkeypatch")
     mp.setattr(requests.Session, 'request', post_mockreturn)
     return mp
 
@@ -79,6 +86,7 @@ def test_query_region(patch_post, patch_parse_coordinates):
         assert result['Start_Time'][0] == b'83-Sep-27 09:19:30'
     assert result['RA'][0] == b'04h33m11.096s'
 
+
 def test_query_region_archive(patch_post, patch_parse_coordinates):
     result = nrao.core.Nrao.query_region(
         commons.ICRSCoordGenerator("05h35.8m 35d43m"), querytype='ARCHIVE')
