@@ -1,10 +1,9 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import os
 import re
-import requests
 
 from astropy.extern import six
-from astropy.tests.helper import pytest
+import pytest
 import astropy.units as u
 from astropy.table import Table
 import numpy as np
@@ -13,6 +12,7 @@ from ... import simbad
 from ...utils.testing_tools import MockResponse
 from ...utils import commons
 from ...exceptions import TableParseError
+from .test_simbad_remote import multicoords
 
 GALACTIC_COORDS = commons.GalacticCoordGenerator(l=-67.02084, b=-29.75447,
                                                  unit=(u.deg, u.deg))
@@ -38,7 +38,7 @@ DATA_FILES = {
 class MockResponseSimbad(MockResponse):
     query_regex = re.compile(r'query\s+([a-z]+)\s+')
 
-    def __init__(self, script, **kwargs):
+    def __init__(self, script, cache=True, **kwargs):
         # preserve, e.g., headers
         super(MockResponseSimbad, self).__init__(**kwargs)
         self.content = self.get_content(script)
@@ -58,13 +58,22 @@ def data_path(filename):
 
 @pytest.fixture
 def patch_post(request):
-    mp = request.getfuncargvalue("monkeypatch")
-    mp.setattr(requests, 'post', post_mockreturn)
+    try:
+        mp = request.getfixturevalue("monkeypatch")
+    except AttributeError:  # pytest < 3
+        mp = request.getfuncargvalue("monkeypatch")
+    mp.setattr(simbad.SimbadClass, '_request', post_mockreturn)
     return mp
 
 
-def post_mockreturn(url, data, timeout, **kwargs):
+def post_mockreturn(self, method, url, data, timeout, **kwargs):
     response = MockResponseSimbad(data['script'], **kwargs)
+
+    class last_query(object):
+        pass
+
+    self._last_query = last_query()
+    self._last_query.data = data
     return response
 
 
@@ -125,20 +134,12 @@ def test_parse_result():
     assert isinstance(simbad.Simbad.last_response.text, six.string_types)
     assert isinstance(simbad.Simbad.last_response.content, six.binary_type)
 
+
 votable_fields = ",".join(simbad.core.Simbad.get_votable_fields())
 
 
 @pytest.mark.parametrize(('args', 'kwargs', 'expected_script'),
-                         [([ICRS_COORDS], dict(radius=5.0 * u.deg,
-                                               frame='ICRS',
-                                               equinox=2000.0, epoch='J2000',
-                                               caller='query_region_async'),
-                           ("\nvotable {" + votable_fields + "}\n"
-                            "votable open\n"
-                            "query coo  5:35:17.3 -80:52:00 "
-                            "radius=5.0d frame=ICRS equi=2000.0 epoch=J2000 \n"
-                            "votable close")),
-                          (["m [0-9]"], dict(wildcard=True,
+                         [(["m [0-9]"], dict(wildcard=True,
                                              caller='query_object_async'),
                            ("\nvotable {" + votable_fields + "}\n"
                             "votable open\n"
@@ -147,7 +148,7 @@ votable_fields = ",".join(simbad.core.Simbad.get_votable_fields())
                             )),
                           (["2006ApJ"], dict(caller='query_bibcode_async',
                                              get_raw=True),
-                           ("\n\n\nquery bibcode  2006ApJ  \n"))
+                           ("\n\nquery bibcode  2006ApJ  \n"))
                           ])
 def test_args_to_payload(args, kwargs, expected_script):
     script = simbad.Simbad._args_to_payload(*args, **kwargs)['script']
@@ -157,12 +158,15 @@ def test_args_to_payload(args, kwargs, expected_script):
 @pytest.mark.parametrize(('epoch', 'equinox'),
                          [(2000, 'thousand'),
                           ('J-2000', None),
-                          (None, '10e3')
+                          (None, '10e3b')
                           ])
-def test_args_to_payload_validate(epoch, equinox):
-    with pytest.raises(Exception):
-        simbad.Simbad._args_to_payload(caller='query_region_async',
-                                       epoch=epoch, equinox=equinox)
+def test_validation(epoch, equinox):
+    with pytest.raises(ValueError):
+        # only one of these has to raise an exception
+        if equinox is not None:
+            simbad.core.validate_equinox(equinox)
+        if epoch is not None:
+            simbad.core.validate_epoch(epoch)
 
 
 @pytest.mark.parametrize(('bibcode', 'wildcard'),
@@ -232,10 +236,11 @@ def test_query_catalog(patch_post):
 
 
 @pytest.mark.parametrize(('coordinates', 'radius', 'equinox', 'epoch'),
-                         [(ICRS_COORDS, None, None, None),
+                         [(ICRS_COORDS, None, 2000.0, 'J2000'),
                           (GALACTIC_COORDS, 5 * u.deg, 2000.0, 'J2000'),
-                          (FK4_COORDS, '5d0m0s', None, None),
-                          (FK5_COORDS, None, None, None)
+                          (FK4_COORDS, '5d0m0s', 2000.0, 'J2000'),
+                          (FK5_COORDS, None, 2000.0, 'J2000'),
+                          (multicoords, 0.5*u.arcsec, 2000.0, 'J2000'),
                           ])
 def test_query_region_async(patch_post, coordinates, radius, equinox, epoch):
     response1 = simbad.core.Simbad.query_region_async(
@@ -249,10 +254,10 @@ def test_query_region_async(patch_post, coordinates, radius, equinox, epoch):
 
 
 @pytest.mark.parametrize(('coordinates', 'radius', 'equinox', 'epoch'),
-                         [(ICRS_COORDS, None, None, None),
+                         [(ICRS_COORDS, None, 2000.0, 'J2000'),
                           (GALACTIC_COORDS, 5 * u.deg, 2000.0, 'J2000'),
-                          (FK4_COORDS, '5d0m0s', None, None),
-                          (FK5_COORDS, None, None, None)
+                          (FK4_COORDS, '5d0m0s', 2000.0, 'J2000'),
+                          (FK5_COORDS, None, 2000.0, 'J2000')
                           ])
 def test_query_region(patch_post, coordinates, radius, equinox, epoch):
     result1 = simbad.core.Simbad.query_region(coordinates, radius=radius,
@@ -264,7 +269,7 @@ def test_query_region(patch_post, coordinates, radius, equinox, epoch):
 
 
 @pytest.mark.parametrize(('coordinates', 'radius', 'equinox', 'epoch'),
-                         [(ICRS_COORDS, 0, None, None)])
+                         [(ICRS_COORDS, 0, 2000.0, 'J2000')])
 def test_query_region_radius_error(patch_post, coordinates, radius,
                                    equinox, epoch):
     with pytest.raises(u.UnitsError):
@@ -277,7 +282,7 @@ def test_query_region_radius_error(patch_post, coordinates, radius,
 
 
 @pytest.mark.parametrize(('coordinates', 'radius', 'equinox', 'epoch'),
-                         [(ICRS_COORDS, "0d", None, None),
+                         [(ICRS_COORDS, "0d", 2000.0, 'J2000'),
                           (GALACTIC_COORDS, 1.0 * u.marcsec, 2000.0, 'J2000')
                           ])
 def test_query_region_small_radius(patch_post, coordinates, radius,
@@ -352,9 +357,11 @@ def test_votable_fields():
 
 
 def test_query_criteria1(patch_post):
-    result = simbad.core.Simbad.query_criteria(
+    Simbad = simbad.core.Simbad()
+    result = Simbad.query_criteria(
         "region(box, GAL, 49.89 -0.3, 0.5d 0.5d)", otype='HII')
     assert isinstance(result, Table)
+    assert "region(box, GAL, 49.89 -0.3, 0.5d 0.5d)" in Simbad._last_query.data['script']
 
 
 def test_query_criteria2(patch_post):
@@ -364,6 +371,7 @@ def test_query_criteria2(patch_post):
     assert S.get_votable_fields() == ['main_id', 'ra(d)', 'dec(d)']
     result = S.query_criteria(otype='SNR')
     assert isinstance(result, Table)
+    assert 'otype=SNR' in S._last_query.data['script']
 
 
 def test_simbad_settings1():
@@ -385,13 +393,11 @@ def test_simbad_settings2():
 def test_regression_votablesettings():
     assert simbad.Simbad.get_votable_fields() == ['main_id', 'coordinates']
     simbad.core.Simbad.add_votable_fields('ra', 'dec(5)')
-    with pytest.raises(KeyError) as ex:
-        simbad.core.Simbad.add_votable_fields('ra(d)', 'dec(d)')
-    assert ex.value.args[0] == ('ra(d): field already present. Fields '
-                                'ra,dec,id,otype, and bibcodelist can only '
-                                'be specified once.  To change their options, '
-                                'first remove the existing entry, then add '
-                                'a new one.')
+    # this is now allowed:
+    simbad.core.Simbad.add_votable_fields('ra(d)', 'dec(d)')
+    assert simbad.Simbad.get_votable_fields() == ['main_id', 'coordinates',
+                                                  'ra', 'dec(5)', 'ra(d)',
+                                                  'dec(d)']
     # cleanup
     simbad.core.Simbad.remove_votable_fields('ra', 'dec', strip_params=True)
     assert simbad.Simbad.get_votable_fields() == ['main_id', 'coordinates']
