@@ -99,9 +99,11 @@ class TemplateClass(BaseQuery):
         # 2. If get_query_payload is `True` then simply return this dict.
         # 3. Else make the actual HTTP request and return the corresponding
         #    HTTP response
-        # All HTTP requests are made via the `commons.send_request` method.
-        # This uses the Python Requests library internally, and also takes
-        # care of error handling.
+        # All HTTP requests are made via the `BaseQuery._request` method. This
+        # use a generic HTTP request method internally, similar to
+        # `requests.Session.request` of the Python Requests library, but
+        # with added caching-related tools.
+
         # See below for an example:
 
         # first initialize the dictionary of HTTP request parameters
@@ -195,8 +197,8 @@ class TemplateClass(BaseQuery):
             # do something with regex to get the result into
             # astropy.Table form. return the Table.
             pass
-        except:
-            # catch common errors here
+        except ValueError:
+            # catch common errors here, but never use bare excepts
             # return raw result/ handle in some way
             pass
 
@@ -273,7 +275,8 @@ class TemplateClass(BaseQuery):
     # links for the images as a list
 
     @prepend_docstr_noreturns(get_images.__doc__)
-    def get_image_list(self, coordinates, radius, get_query_payload=False):
+    def get_image_list(self, coordinates, radius, get_query_payload=False,
+                       cache=True):
         """
         Returns
         -------
@@ -291,10 +294,10 @@ class TemplateClass(BaseQuery):
         request_payload = self._args_to_payload(coordinates, radius)
         if get_query_payload:
             return request_payload
-        response = commons.send_request(self.URL,
-                                        request_payload,
-                                        self.TIMEOUT,
-                                        request_type='GET')
+        response = self._request(method="GET", url=self.URL,
+                                 data=request_payload,
+                                 timeout=self.TIMEOUT, cache=cache)
+
         return self.extract_image_urls(response.text)
 
     # the extract_image_urls method takes in the HTML page as a string
@@ -318,6 +321,7 @@ class TemplateClass(BaseQuery):
         # return the list of image URLs
         pass
 
+
 # the default tool for users to interact with is an instance of the Class
 Template = TemplateClass()
 
