@@ -3,6 +3,7 @@
 Common non-package specific utility
 functions that will ultimately be merged into `astropy.utils`.
 """
+import warnings
 
 from .progressbar import *
 from .download_file_list import *
@@ -10,4 +11,3 @@ from .class_or_instance import *
 from .commons import *
 from .process_asyncs import async_to_sync
 from .docstr_chompers import prepend_docstr_noreturns
-from .testing_tools import turn_off_internet, turn_on_internet
