@@ -21,12 +21,10 @@ def async_to_sync(cls):
 
         @class_or_instance
         def newmethod(self, *args, **kwargs):
-            if 'verbose' in kwargs:
-                verbose = kwargs.pop('verbose')
-            else:
-                verbose = False
+            verbose = kwargs.pop('verbose', False)
+
             response = getattr(self, async_method_name)(*args, **kwargs)
-            if kwargs.get('get_query_payload'):
+            if kwargs.get('get_query_payload') or kwargs.get('field_help'):
                 return response
             result = self._parse_result(response, verbose=verbose)
             self.table = result
@@ -42,8 +40,8 @@ def async_to_sync(cls):
 
             newmethod = create_method(k)
 
-            newmethod.fn.__doc__ = async_to_sync_docstr(getattr(cls, k).__doc__)
-            # newmethod.__doc__ = async_to_sync_docstr(getattr(cls,k).__doc__) # for using decorator module
+            newmethod.fn.__doc__ = async_to_sync_docstr(
+                getattr(cls, k).__doc__)
 
             newmethod.fn.__name__ = newmethodname
             newmethod.__name__ = newmethodname
@@ -65,7 +63,8 @@ def async_to_sync_docstr(doc, returntype='table'):
                    'fits': '~astropy.io.fits.PrimaryHDU',
                    'dict': 'dict'}
 
-    firstline = "Queries the service and returns a {rt} object.\n".format(rt=returntype)
+    firstline = ("Queries the service and returns a {rt} object.\n"
+                 .format(rt=returntype))
 
     vowels = 'aeiou'
     vowels += vowels.upper()
@@ -83,6 +82,7 @@ def async_to_sync_docstr(doc, returntype='table'):
     outlines = remove_returns(doc.lstrip('\n'))
 
     # then the '' here is to add back the blank line
-    newdoc = "\n".join(['', firstline] + outlines + [textwrap.dedent(returnstr)])
+    newdoc = "\n".join(
+        ['', firstline] + outlines + [textwrap.dedent(returnstr)])
 
     return newdoc
