@@ -1,23 +1,25 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-import requests
-from astropy.extern.six.moves import urllib
-from astropy.extern import six
-import astropy.coordinates as coord
-import astropy.units as u
-from ...utils import chunk_read, chunk_report
-from ...utils import class_or_instance
-from ...utils import commons
-from ...utils.process_asyncs import async_to_sync_docstr, async_to_sync
-from ...utils.docstr_chompers import remove_returns, prepend_docstr_noreturns
-from astropy.table import Table
-from astropy.tests.helper import pytest, remote_data
-import astropy.io.votable as votable
-import textwrap
+
 from collections import OrderedDict
 import os
-from astropy.io import fits
-import astropy.utils.data as aud
+import requests
+import pytest
 import tempfile
+import textwrap
+
+import astropy.coordinates as coord
+from astropy.extern.six.moves import urllib
+from astropy.extern import six
+from astropy.io import fits
+import astropy.io.votable as votable
+import astropy.units as u
+from astropy.table import Table
+from astropy.tests.helper import remote_data
+import astropy.utils.data as aud
+
+from ...utils import chunk_read, chunk_report, class_or_instance, commons
+from ...utils.process_asyncs import async_to_sync_docstr, async_to_sync
+from ...utils.docstr_chompers import remove_returns, prepend_docstr_noreturns
 
 
 class SimpleQueryClass(object):
@@ -70,19 +72,6 @@ def test_parse_coordinates_3():
         commons.parse_coordinates(9.8 * u.kg)
 
 
-# this test fails to fail appropriately, apparently...
-# I get a "DID NOT RAISE" failure running locally,
-# even though every interactive test I have tried DOES
-# raise an exception.
-@pytest.mark.parametrize(('radius'),
-                         [5,
-                          # 9.8 * u.kg
-                          ])
-def test_parse_radius_2(radius):
-    with pytest.raises(Exception):
-        commons.parse_radius(radius)
-
-
 def test_send_request_post(monkeypatch):
     def mock_post(url, data, timeout, headers={}, status_code=200):
         class SpecialMockResponse(object):
@@ -138,6 +127,7 @@ def test_send_request_err():
         commons.send_request('https://github.com/astropy/astroquery',
                              dict(a='b'), 60, request_type='PUT')
 
+
 col_1 = [1, 2, 3]
 col_2 = [0, 1, 0, 1, 0, 1]
 col_3 = ['v', 'w', 'x', 'y', 'z']
@@ -292,6 +282,7 @@ def test_async_to_sync(cls=Dummy):
     newcls = async_to_sync(Dummy)
     assert hasattr(newcls, "do_nothing")
 
+
 docstr3 = """
     Returns
     -------
@@ -325,6 +316,7 @@ def dummyfunc():
     """
     pass
 
+
 docstr4 = """
     Blah Blah Blah
 
@@ -372,6 +364,7 @@ def test_payload_return(cls=DummyQuery):
     result = DummyQuery.query(get_query_payload=False)
     assert isinstance(result, six.string_types)
 
+
 fitsfilepath = os.path.join(os.path.dirname(__file__),
                             '../../sdss/tests/data/emptyfile.fits')
 
